<?php
/*
Plugin Name: E-Section
Plugin URI: http://yourdomain.com/
Description: Allows you to manage your posts by section / page
Version: 2.1
Author: Don Kukral
Author URI: http://yourdomain.com
License: GPL
*/
//ini_set('display_errors', 1);
//ini_set("log_errors", 0);
//ini_set("error_log", "/tmp/php-error.log");

define( 'E_SECTION_VERSION' , '2.0' );
define( 'E_SECTION_ROOT' , dirname(__FILE__) );
define( 'E_SECTION_URL' , plugins_url(plugin_basename(dirname(__FILE__)).'/') );
define( 'E_SECTION_PAGE', 'e-section');
define( 'E_SECTION_PAGE_PLANNER_PAGE', 'e-section-edition-planner');
define( 'E_SECTION_ADMIN', get_admin_url() . "admin.php?page=" . E_SECTION_PAGE);
define( 'E_SECTION_PAGE_PLANNER_ADMIN', get_admin_url() . "admin.php?page=" . E_SECTION_PAGE_PLANNER_PAGE);

global $e_section_db_ver;
$e_section_db_ver = "1.0";

include_once('php/functions.php');
include_once("php/logger.php");
include_once("php/geo.php");
include_once("php/print-tags.php");
include_once("php/export-posts.php");
include_once("php/page-planner.php");
include_once("php/additional-sections.php");
include_once("php/widget.php");
include_once("php/reader_report.php");

$esection = new eSection();

add_action( 'admin_menu', array( &$esection, 'menu' ) );
add_action( 'template_redirect', array( &$esection->logger, 'logger' ) );
add_action( 'admin_enqueue_scripts', array( &$esection,'e_section_admin_scripts' ) );
add_action( 'admin_print_styles', array( &$esection, 'e_section_admin_styles' ) );
add_action( 'admin_menu', array(&$esection->print_tags, 'print_tags_add_custom_box'));
add_action( 'admin_menu', array(&$esection->export_posts, 'export_posts_quick_add_custom_box'));
add_action( 'save_post', array(&$esection->print_tags, 'print_tags_update_tags'));

class eSection {

    function __construct() {
        $this->logger = new logger();
        $this->geo = new geo();
        $this->print_tags = new print_tags();
        $this->export_posts = new export_posts();
        $this->page_planner = new page_planner();
        $this->additional_sections = new additional_sections();
        $this->widget = new e_section_widget();
        $this->reader_report = new reader_report();

        $this->pages = array(
            'e-section' => $this,
            'e-section-logger' => $this->logger,
            'e-section-geo-logger' => $this->geo,
            'e-section-print-tags' => $this->print_tags,
            'e-section-additional-sections' => $this->additional_sections,
            'e-section-export-posts' => $this->export_posts,
            'e-section-edition-planner' => $this->page_planner,
            'e-section-widget' => $this->widget,
            'e-section-reader-report' => $this->reader_report,
            );

    }

    function e_section_admin_scripts() {
        if ((array_key_exists('page', $_GET)) &&
            (in_array($_GET['page'], array_keys($this->pages)))) {
                wp_enqueue_script( 'jquery' );
    	    wp_enqueue_script("e-section-js", E_SECTION_URL . "js/e-section.js", array('jquery'), '1.0');
            wp_enqueue_script('e-section-jquery-ui', E_SECTION_URL . 'js/jquery-ui-1.8.18.custom.min.js', array('jquery'), E_SECTION_VERSION, true);
		} elseif (strstr($_SERVER['REQUEST_URI'], 'wp-admin/post-new.php') || strstr($_SERVER['REQUEST_URI'], 'wp-admin/post.php') ||
            strstr($_SERVER['REQUEST_URI'], 'wp-admin/edit.php') || ($_SERVER['REQUEST_URI'] == '/wp-admin/index.php') || ($_SERVER['REQUEST_URI'] == '/wp-admin/')) {
    	    wp_enqueue_script("e-section-js", E_SECTION_URL . "js/e-section.js", array('jquery'), '1.0');
            wp_enqueue_script('e-section-jquery-ui', E_SECTION_URL . 'js/jquery-ui-1.8.18.custom.min.js', array('jquery'), E_SECTION_VERSION, true);
    	} else {
    	    wp_deregister_script("e-section-js");
            wp_deregister_script('e-section-jquery-ui');
    	}

    }

    function e_section_admin_styles() {
        if ((array_key_exists('page', $_GET)) &&
            (in_array($_GET['page'], array_keys($this->pages)))) {
            wp_enqueue_style( 'e-section-css', E_SECTION_URL . 'css/e-section.css', false );
            wp_enqueue_style( 'e-section-jquery-ui-css', E_SECTION_URL . 'css/smoothness/jquery-ui-1.8.18.custom.css', false );
		} elseif (strstr($_SERVER['REQUEST_URI'], 'wp-admin/post-new.php') || strstr($_SERVER['REQUEST_URI'], 'wp-admin/post.php') ||
            strstr($_SERVER['REQUEST_URI'], 'wp-admin/edit.php') || ($_SERVER['REQUEST_URI'] == '/wp-admin/index.php') || ($_SERVER['REQUEST_URL'] == '/wp-admin/'))  {
            wp_enqueue_style( 'e-section-css', E_SECTION_URL . 'css/e-section.css', false );
            wp_enqueue_style( 'e-section-jquery-ui-css', E_SECTION_URL . 'css/smoothness/jquery-ui-1.8.18.custom.css', false );
        } else {
            wp_deregister_style('e-section-css');
            wp_deregister_style('e-section-jquery-ui-css');
        }
    }

    function menu() {
        return add_menu_page('E-Section', 'E-Section', 'manage_options', 'e-section', array(&$this, "display_page" ) ) &&
            add_submenu_page('e-section', 'Print Tags', 'Print Tags', 'read', 'e-section-print-tags', array(&$this, "display_page")) &&
            add_submenu_page('e-section', 'Additional Sections', 'Additional Sections', 'read', 'e-section-additional-sections', array(&$this, "display_page")) &&
            add_submenu_page('e-section', 'Export Posts', 'Export Posts', 'read', 'e-section-export-posts', array(&$this, "display_page")) &&
            add_submenu_page('e-section', 'Edition Planner', 'Edition Planner', 'read', 'e-section-edition-planner', array(&$this, "display_page")) &&
            add_submenu_page('e-section', 'Logger', 'Logger', 'read', 'e-section-logger', array(&$this, "display_page")) &&
            add_submenu_page('e-section', 'GEO Logger', 'GEO Logger', 'read', 'e-section-geo-logger', array(&$this, "display_page")) && 
            add_submenu_page('e-section', 'Readership Report', 'Readership Report', 'read', 'e-section-reader-report', array(&$this, "display_page"));
    }

    function display_page() {
        $page = $_GET['page'];
        if (in_array($page, array_keys($this->pages))) {
            $this->pages[$page]->view();
        } else {
            $this->soon();
        }
    }

    function view() {
        ?>
        	<div class="wrap" id="e-section-wrap">
        	    <div id="e-section-title">
        	        <h2>E-Section</h2>
        	    </div>
        	</div>
        <?php
        echo "default view";
    }

    function soon() {
        ?>
        	<div class="wrap" id="e-section-wrap">
        	    <div id="e-section-title">
        	        <h2>E-Section</h2>
        	    </div>
        	</div>
        <?php
        echo "coming soon";
    }
}


function e_section_install() {
    global $wpdb;
    global $e_section_db_ver;

    if ($e_section_db_ver == get_option('e_section_db_ver')) { return; }

    $table_name = $wpdb->prefix . "e_section";

    $sql = "CREATE TABLE " . $table_name . " (
        id MEDIUMINT(9) NOT NULL AUTO_INCREMENT,
        section VARCHAR(25) NOT NULL,
        page VARCHAR(25) NOT NULL,
        city VARCHAR(255) NOT NULL DEFAULT '',
        postal_code VARCHAR(25) NOT NULL DEFAULT '',
        ts TIMESTAMP NOT NULL,
        UNIQUE KEY id (id))
        KEY 'ts_idx' ('ts')";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);

    $print_tag_options = array();
    $print_tag_options['section_name_1'] = 'A';
    $print_tag_options['section_name_2'] = 'B';
    $print_tag_options['section_name_3'] = 'C';
    $print_tag_options['section_name_4'] = 'D';
    $print_tag_options['page_count_1'] = 1;
    $print_tag_options['page_count_2'] = 1;
    $print_tag_options['page_count_3'] = 1;
    $print_tag_options['page_count_4'] = 1;
    $print_tag_options['number_of_sections']  = 4;
    update_option('print_tag_options', $print_tag_options);
    update_option('export_posts_tag', 'printed');
    update_option('export_posts_no_posts', 150);

    add_option("e_section_db_ver", $e_section_db_ver);

}

function e_section_update_check() {
    global $e_section_db_ver;
    if (get_site_option('e_section_db_ver') != $e_section_db_ver) {
        e_section_install();
    }
}

register_activation_hook(__FILE__, 'e_section_install');
//add_action( 'plugins_loaded', 'e_section_update_check');

/*
if ( ! function_exists("getESectionDate")) {
    function getESectionDate($custom="") {
        date_default_timezone_set('America/Los_Angeles');

        $makeDate = strtotime("today");

        $build[0] = date("Y-m-d", $makeDate);
        $build[1] = date("l, M j", $makeDate);
        $build[2] = date("Ymd", $makeDate);
        $build[3] = date("m-d-Y", $makeDate);
        $build[4] = date("l, F j, Y", $makeDate);
        $build[5] = date("m-d-Y", $makeDate);
        $build[6] = date("M d Y", $makeDate);
        $build['m'] = date("n", $makeDate);
        $build['d'] = date("d", $makeDate);
        $build['y'] = date("Y", $makeDate);
        return $build;

    }
}
*/
?>
